@@ -37,6 +37,8 @@ class Job;
 }
 
 /**
+ * @class KRun krun.h <KRun>
+ *
  * To open files with their associated applications in KDE, use KRun.
  *
  * It can execute any desktop entry, as well as any file, using
@@ -211,6 +213,10 @@ public:
     /**
      * Open a list of URLs with a certain service (application).
      *
+     * Prefer runApplication(), unless you need to wait for the application
+     * to register to DBus before this method returns (but that should rather
+     * be done with DBus activation).
+     *
      * @param service the service to run
      * @param urls the list of URLs, can be empty (app launched
      *        without argument)
@@ -224,7 +230,33 @@ public:
      */
     static qint64 runService(const KService &service, const QList<QUrl> &urls, QWidget *window,
                              bool tempFiles = false, const QString &suggestedFileName = QString(),
-                             const QByteArray &asn = QByteArray());
+                             const QByteArray &asn = QByteArray()); // TODO KF6: deprecate/remove
+
+    enum RunFlag {
+        DeleteTemporaryFiles = 0x1, ///< the URLs passed to the service will be deleted when it exits (if the URLs are local files)
+        RunExecutables = 0x2,       ///< Whether to run URLs that are executable scripts or binaries @see isExecutableFile() @since 5.31
+    };
+    Q_DECLARE_FLAGS(RunFlags, RunFlag)
+
+    /**
+     * Run an application (known from its .desktop file, i.e. as a KService)
+     *
+     * Unlike runService, this does not wait for the application to register to DBus
+     * before returning. Such behavior is better done with DBus activation anyway.
+     *
+     * @param service the service to run
+     * @param urls the list of URLs, can be empty (app launched
+     *        without argument)
+     * @param window The top-level widget of the app that invoked this object.
+     * @param flags various flags
+     * @param suggestedFileName see setSuggestedFileName
+     * @param asn Application startup notification id, if any (otherwise "").
+     * @return 0 on error, the process ID on success
+     * @since 5.24
+     */
+    static qint64 runApplication(const KService &service, const QList<QUrl> &urls, QWidget *window,
+                                 RunFlags flags = RunFlags(), const QString &suggestedFileName = QString(),
+                                 const QByteArray &asn = QByteArray());
 
     /**
      * Open a list of URLs with an executable.
@@ -264,9 +296,30 @@ public:
      * @param suggestedFileName see setSuggestedFileName
      * @param asn Application startup notification id, if any (otherwise "").
      * @return @c true on success, @c false on error
+     * @deprecated since 5.31, use runUrl() with RunFlags instead.
      */
-    static bool runUrl(const QUrl &url, const QString &mimetype, QWidget *window,
-                       bool tempFile = false, bool runExecutables = true,
+#ifndef KIOWIDGETS_NO_DEPRECATED
+    static bool KIOWIDGETS_DEPRECATED runUrl(const QUrl &url, const QString &mimetype, QWidget *window,
+                                             bool tempFile = false, bool runExecutables = true,
+                                             const QString &suggestedFileName = QString(), const QByteArray &asn = QByteArray());
+#endif
+
+    /**
+     * Open the given URL.
+     *
+     * This function can be used after the mime type has been found out.
+     * It will search for all services which can handle the mime type and call run() afterwards.
+     *
+     * @param url The URL to open.
+     * @param mimetype The mime type of the resource.
+     * @param window The top-level widget of the app that invoked this object.
+     * @param flags Various run flags.
+     * @param suggestedFileName See setSuggestedFileName()
+     * @param asn Application startup notification id, if any (otherwise "").
+     * @return @c true on success, @c false on error
+     * @since 5.31
+     */
+    static bool runUrl(const QUrl &url, const QString &mimetype, QWidget *window, RunFlags flags,
                        const QString &suggestedFileName = QString(), const QByteArray &asn = QByteArray());
 
     /**
@@ -383,7 +436,7 @@ public:
      * To be executable the file must pass the following rules:
      * -# Must reside on the local filesystem.
      * -# Must be marked as executable for the user by the filesystem.
-     * -# The mime type must inherit application/x-executable or application/x-executable-script.
+     * -# The mime type must inherit application/x-executable, application/x-executable-script or application/x-sharedlib.
      * To allow a script to run when the above rules are satisfied add the entry
      * @code
      * X-KDE-IsAlso=application/x-executable-script
